@@ -25,36 +25,52 @@ LOT_SETTINGS = getattr(settings, 'LOT', {
         'duration': None,
     },
 })
-LOT_TYPE_CHOICES = [(key, value['name']) for key, value in LOT_SETTINGS.iteritems()]
+LOT_TYPE_CHOICES = [
+    (key, value['name'])
+    for key, value in LOT_SETTINGS.items()
+]
 
 
 class LOT(models.Model):
-    uuid = models.CharField(max_length=50, null=False, blank=False, verbose_name=_('Uuid'))
-    type = models.SlugField(max_length=50, choices=LOT_TYPE_CHOICES, null=False, blank=False,
-                            verbose_name=_('LOT type'))
-    user = models.ForeignKey(get_user_model(), null=False, blank=False, verbose_name=_('user'))
-    session_data = models.TextField(null=True, blank=True, verbose_name=_('Jsoned Session Data'))
-    created = models.DateTimeField(auto_now_add=True, null=False, blank=False, verbose_name=_('creation date'))
+    uuid = models.CharField(_('UUID'), max_length=50)
+    type = models.SlugField(_('LOT type'), max_length=50,
+                            choices=LOT_TYPE_CHOICES)
+    user = models.ForeignKey(get_user_model(), verbose_name=_('user'))
+    session_data = models.TextField(_('Jsoned Session Data'), blank=True)
+    created = models.DateTimeField(_('Creation date'), auto_now_add=True)
 
     def verify(self):
-        if not self.type in LOT_SETTINGS:
+        if self.type not in LOT_SETTINGS:
             return False
 
-        duration = LOT_SETTINGS.get(self.type, {}).get('duration', None)
+        verify_setting = LOT_SETTINGS[self.type]
+
+        duration = verify_setting.get('duration', None)
+        verify_func = verify_setting.get('verify-func', lambda x: True)
+
+        if not verify_func(self):
+            return False
 
         if duration is None:
             return True
 
         return (now() - self.created).total_seconds() < duration
 
+    def delete_on_fail(self):
+        if self.type not in LOT_SETTINGS:
+            return True
+
+        return LOT_SETTINGS[self.type].get('delete-on-fail', True)
+
     def is_one_time(self):
         return LOT_SETTINGS.get(self.type, {}).get('one-time', False)
 
     def save(self, *args, **kwargs):
         if self.id and not kwargs.pop('force_modification', False):
-            raise Exception('Modification not allowed (you can force it with the force_modification parameter on save)')
+            raise Exception('Modification not allowed without '
+                            'force_modification parameter on save.')
         self.uuid = uuid4()
         super(LOT, self).save(*args, **kwargs)
 
     def __unicode__(self):
-        return "{0} ({1})".format(self.get_type_display(), self.uuid)
+        return u"{0} ({1})".format(self.get_type_display(), self.uuid)
